/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a copy
 * of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.geoviewer.jxmap.render;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.MultiPolygon;
import java.awt.Graphics2D;
import java.awt.Polygon;
import java.awt.geom.Point2D;
import org.jdesktop.swingx.JXMapViewer;
import org.jdesktop.swingx.mapviewer.GeoPosition;

/**
 *
 * @author Timon Veenstra
 */
public class MultiPolygonRenderer extends GeometryRenderer<MultiPolygon> {

    @Override
    public void render(MultiPolygon geometry, JXMapViewer mapViewer, Graphics2D g) {

        com.vividsolutions.jts.geom.Point centroid = geometry.getCentroid();

//        g.translate(bounds.x, bounds.y);
//        g.setClip(bounds);

        //
        // draw the geometry
        //
        Polygon polygon = new Polygon();
        if (geometry.getCoordinates().length > 1) {
            int pointX = 0;
            int pointY = 0;
            for (Coordinate coordinate : geometry.getCoordinates()) {
                GeoPosition geopoint = new GeoPosition(coordinate.y, coordinate.x);
                Point2D point2D = mapViewer.getTileFactory().geoToPixel(geopoint, mapViewer.getZoom());

                pointX = (int) (point2D.getX() - mapViewer.getViewportBounds().getX());
                pointY = (int) (point2D.getY() - mapViewer.getViewportBounds().getY());

                polygon.addPoint(pointX, pointY);
            }
            g.clip(polygon);
            // fallback to old painting if the background painter is null
            g.fill(polygon);
        }
    }
}
